Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BinaryCache ¶
type BinaryCache struct {
// contains filtered or unexported fields
}
BinaryCache holds the path to compiled binaries
func NewBinaryCache ¶
func NewBinaryCache() *BinaryCache
NewBinaryCache creates a new value of type BinaryCache pointer. This stores a URL as the key and a path to the compiled binary as the value
func (*BinaryCache) Get ¶
func (b *BinaryCache) Get(k string) string
Get takes a key as an argument and gets the associated value if it exists
func (*BinaryCache) Set ¶
func (b *BinaryCache) Set(k, v string)
Set takes a key and a value and sets them in the cache
type JLS ¶
type JLS struct {
Host string `json:"host"`
IP4 string `json:"ip4"`
IP6 string `json:"ip6"`
JID int `json:"jid"`
Name string `json:"name"`
OSRelease string `json:"OSRelease"`
Path string `json:"path"`
Hostname string `json:"hostname"`
}
JLS holds the Go represented output from the jls command
type JailServicer ¶
type JailServicer interface {
InitializeSystem() error
CreateJail(string, bool) error
RemoveJail(string) error
KillJail(int) error
JailDetails(int) (*JLS, error)
}
JailServicer defines the behavior of the Jail service
type NetworkServicer ¶
type NetworkServicer interface {
Allocate([]byte) (string, error)
Pool() map[string][]byte
UpdateIPState(string, []byte) error
}
NetworkServicer defines the behavior of the IP service
func NewNetworkService ¶
func NewNetworkService(conf *config.Config, l gklog.Logger, metrics *statsd.Client) (NetworkServicer, error)
NewNetworkService creates a new value of type networkService pointer
Click to show internal directories.
Click to hide internal directories.